From: Marco d'Itri <md@linux.it>
Subject: change some settings in autoconf.hin
Forwarded: not-needed

--- a/include/autoconf.hin
+++ b/include/autoconf.hin
@@ -1017,6 +1017,10 @@ Added missing headers after gettext upda
  */
 #	undef USE_ZLIB
 
+/* debian-specific */
+#define XFACE_ABLE
+#define NNTP_SERVER_FILE "/etc/news/server"
+
 /*
  * signal-types
  */
